@@ -24,6 +24,9 @@
 #'
 #' @details
 #'
+#' See the \href{http://rmarkdown.rstudio.com/beamer_presentation_format.html}{online
+#' documentation} for additional details on using the \code{beamer_presentation} format.
+#'
 #' Creating Beamer output from R Markdown requires that LaTeX be installed.
 #'
 #' For more information on markdown syntax for presentations see
@@ -35,10 +38,9 @@
 #' see the documentation on R Markdown \link[=rmd_metadata]{metadata}.
 #'
 #' R Markdown documents also support citations. You can find more information on
-#' the markdown syntax for citations within the pandoc documentation on
-#' \href{http://johnmacfarlane.net/pandoc/demo/example19/Citations.html}{citations}
-#' and
-#' \href{http://johnmacfarlane.net/pandoc/demo/example19/Footnotes.html}{footnotes}.
+#' the markdown syntax for citations in the
+#' \href{http://rmarkdown.rstudio.com/authoring_bibliographies_and_citations.html}{Bibliographies
+#' and Citations} article in the online documentation.
 #'
 #' @examples
 #' \dontrun{
@@ -68,6 +70,7 @@ beamer_presentation <- function(toc = FALSE,
                                 template = "default",
                                 keep_tex = FALSE,
                                 includes = NULL,
+                                md_extensions = NULL,
                                 pandoc_args = NULL) {
 
   # base pandoc options for all beamer output
@@ -115,7 +118,7 @@ beamer_presentation <- function(toc = FALSE,
   output_format(
     knitr = knitr_options_pdf(fig_width, fig_height, fig_crop, dev),
     pandoc = pandoc_options(to = "beamer",
-                            from = from_rmarkdown(fig_caption),
+                            from = from_rmarkdown(fig_caption, md_extensions),
                             args = args,
                             keep_tex = keep_tex),
     clean_supporting = !keep_tex
