@@ -15,8 +15,11 @@
 #'  presentation using the 'S' (smaller) and 'B' (bigger) keys.
 #' 
 #' @return R Markdown output format to pass to \code{\link{render}}
-#'   
+#' 
 #' @details
+#'
+#' See the \href{http://rmarkdown.rstudio.com/slidy_presentation_format.html}{online
+#' documentation} for additional details on using the \code{slidy_presentation} format.
 #' 
 #' For more information on markdown syntax for presentations see 
 #' \href{http://johnmacfarlane.net/pandoc/demo/example9/producing-slide-shows-with-pandoc.html}{producing
@@ -53,6 +56,7 @@ slidy_presentation <- function(incremental = FALSE,
                                includes = NULL,
                                keep_md = FALSE,
                                lib_dir = NULL,
+                               md_extensions = NULL,
                                pandoc_args = NULL,
                                ...) {
 
@@ -106,7 +110,7 @@ slidy_presentation <- function(incremental = FALSE,
     # slidy
     slidy_path <- rmarkdown_system_file("rmd/slidy/Slidy2")
     if (!self_contained)
-      slidy_path <- relative_to(
+      slidy_path <- normalized_relative_to(
         output_dir, render_supporting_files(slidy_path, lib_dir))
     args <- c(args, "--variable", paste("slidy-url=",
                                         pandoc_path_arg(slidy_path), sep=""))
@@ -122,7 +126,7 @@ slidy_presentation <- function(incremental = FALSE,
   output_format(
     knitr = knitr_options_html(fig_width, fig_height, fig_retina, keep_md, dev),
     pandoc = pandoc_options(to = "slidy",
-                            from = from_rmarkdown(fig_caption),
+                            from = from_rmarkdown(fig_caption, md_extensions),
                             args = args),
     keep_md = keep_md,
     clean_supporting = self_contained,
